==> crun_1.20.orig.tar.gz: crun-1.20/libocispec/image-spec/implementations.md <==
# OCI Image Implementations

Projects or Companies currently adopting the OCI Image Specification

- [projectatomic/skopeo](https://github.com/projectatomic/skopeo)
- [Amazon Elastic Container Registry (ECR)](https://docs.aws.amazon.com/AmazonECR/latest/userguide/image-manifest-formats.html) ([announcement](https://aws.amazon.com/about-aws/whats-new/2017/01/amazon-ecr-supports-docker-image-manifest-v2-schema-2/))
- [Azure Container Registry (ACR)](https://docs.microsoft.com/azure/container-registry/container-registry-image-formats#oci-images)
- [openSUSE/umoci](https://github.com/openSUSE/umoci)
- [cloudfoundry/grootfs](https://github.com/cloudfoundry/grootfs) ([source](https://github.com/cloudfoundry/grootfs/blob/c3da26e1e463b51be1add289032f3dca6698b335/fetcher/remote/docker_src.go))
- [Mesos plans](https://issues.apache.org/jira/browse/MESOS-5011) ([design doc](https://docs.google.com/document/d/1Pus7D-inIBoLSIPyu3rl_apxvUhtp3rp0_b0Ttr2Xww/edit#heading=h.hrvk2wboog4p))
- [Docker](https://github.com/docker)
  - [docker/docker (`docker save/load` WIP)](https://github.com/docker/docker/pull/26369)
  - [distribution/distribution (registry PR)](https://github.com/distribution/distribution/pull/2076)
- [containerd/containerd](https://github.com/containerd/containerd)
- [Containers](https://github.com/containers/)
  - [containers/build](https://github.com/containers/build)
  - [containers/image](https://github.com/containers/image)
  - [containers/oci-spec-rs](https://github.com/containers/oci-spec-rs)
  - [containers/libocispec](https://github.com/containers/libocispec)
- [krustlet/oci-distribution](https://github.com/krustlet/oci-distribution)
- [box-builder/box](https://github.com/box-builder/box)
- [coolljt0725/docker2oci](https://github.com/coolljt0725/docker2oci)
- [regclient/regclient](https://github.com/regclient/regclient)
- [ORAS](https://oras.land/)
  - [oras-project/oras](https://github.com/oras-project/oras/)
  - [oras-project/oras-go](https://github.com/oras-project/oras-go)

## Former Projects

OCI would like to recognize the following projects that are no longer actively maintained but have contributed to the adoption of OCI

- [coreos/rkt](https://github.com/coreos/rkt) - Project ended and archived on Feb 25, 2020

_(to add your project please open a [pull-request](https://github.com/opencontainers/image-spec/pulls))_

==> crun_1.26.orig.tar.gz: crun-1.26/libocispec/image-spec/implementations.md <==
# OCI Image Implementations

Projects or Companies currently adopting the OCI Image Specification

- [Amazon Elastic Container Registry (ECR)](https://docs.aws.amazon.com/AmazonECR/latest/userguide/image-manifest-formats.html) ([announcement](https://aws.amazon.com/about-aws/whats-new/2017/01/amazon-ecr-supports-docker-image-manifest-v2-schema-2/))
- [Azure Container Registry (ACR)](https://docs.microsoft.com/azure/container-registry/container-registry-image-formats#oci-images)
- [openSUSE/umoci](https://github.com/openSUSE/umoci)
- [cloudfoundry/grootfs](https://github.com/cloudfoundry/grootfs) ([source](https://github.com/cloudfoundry/grootfs/blob/c3da26e1e463b51be1add289032f3dca6698b335/fetcher/remote/docker_src.go))
- [Mesos plans](https://issues.apache.org/jira/browse/MESOS-5011) ([design doc](https://docs.google.com/document/d/1Pus7D-inIBoLSIPyu3rl_apxvUhtp3rp0_b0Ttr2Xww/edit#heading=h.hrvk2wboog4p))
- [Docker](https://github.com/docker)
  - [docker/docker (`docker save/load` WIP)](https://github.com/docker/docker/pull/26369)
  - [distribution/distribution (registry PR)](https://github.com/distribution/distribution/pull/2076)
- [containerd/containerd](https://github.com/containerd/containerd)
- [Containers](https://github.com/containers/)
  - [containers/build](https://github.com/containers/build)
  - [containers/image](https://github.com/containers/image)
  - [containers/oci-spec-rs](https://github.com/containers/oci-spec-rs)
  - [containers/libocispec](https://github.com/containers/libocispec)
  - [containers/skopeo](https://github.com/containers/skopeo)
- [coolljt0725/docker2oci](https://github.com/coolljt0725/docker2oci)
- [regclient/regclient](https://github.com/regclient/regclient)
- [ORAS](https://oras.land/)
  - [oras-project/oras](https://github.com/oras-project/oras/)
  - [oras-project/oras-go](https://github.com/oras-project/oras-go)
  - [oras-project/rust-oci-client](https://github.com/oras-project/rust-oci-client)

## Former Projects

OCI would like to recognize the following projects that are no longer actively maintained but have contributed to the adoption of OCI

- [coreos/rkt](https://github.com/coreos/rkt) - Project ended and archived on Feb 25, 2020
- [box-builder/box](https://github.com/box-builder/box) - Project ended and archived on Sep 28, 2020

_(to add your project please open a [pull-request](https://github.com/opencontainers/image-spec/pulls))_
